@@ -5,7 +5,7 @@ use base 'DBIx::Class::Core';
 sub journal_define_table {
     my ( $class, $schema_class, $prefix ) = @_;
 
-    $class->load_components(qw/TimeStamp/);
+    $class->load_components(qw/InflateColumn::DateTime/);
     $class->table($prefix . 'changeset');
 
     $class->add_columns(
@@ -22,7 +22,6 @@ sub journal_define_table {
       },
       set_date => {
          data_type => 'timestamp',
-         set_on_create => 1,
          is_nullable => 0,
       },
       session_id => {
@@ -35,4 +34,16 @@ sub journal_define_table {
     $class->set_primary_key('ID');
 }
 
+sub new {
+    my $self = shift->next::method(@_);
+    # I think we should not do the following and
+    # instead use DBIx::Class::TimeStamp.  If I
+    # can think of a good way (passing a version on
+    # import?) to do it and retain backcompat I will.
+    #
+    # --fREW, 01-27-2010
+    $self->set_date(scalar gmtime);
+    return $self;
+}
+
 1;
